function varargout = szinkevero(varargin)
% SZINKEVERO MATLAB code for szinkevero.fig
%      SZINKEVERO, by itself, creates a new SZINKEVERO or raises the existing
%      singleton*.
%
%      H = SZINKEVERO returns the handle to a new SZINKEVERO or the handle to
%      the existing singleton*.
%
%      SZINKEVERO('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SZINKEVERO.M with the given input arguments.
%
%      SZINKEVERO('Property','Value',...) creates a new SZINKEVERO or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before szinkevero_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to szinkevero_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help szinkevero

% Last Modified by GUIDE v2.5 08-Mar-2013 09:54:55

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @szinkevero_OpeningFcn, ...
                   'gui_OutputFcn',  @szinkevero_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before szinkevero is made visible.
function szinkevero_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to szinkevero (see VARARGIN)

% Choose default command line output for szinkevero
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes szinkevero wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = szinkevero_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
%% saját rész: alapból a megnyitásnál ez jelenik meg
global n;
n=1; %kezdetben ez az 1. map alapból; global, lent a drawimage is látja
szin=rand(30, 30); % 30*30-as random mx
imagesc(szin); %kirajzol mx a plotra (mert máshova nem lehet)
set(handles.colormapkiir, 'String', 'Jet'); %kiírom a mezõbe az aktuális (1.) colormap nevét
%%

% --- Executes on button press in drawimage.
function drawimage_Callback(hObject, eventdata, handles)
% hObject    handle to drawimage (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%% saját rész: draw image gomb megnyomására ez történik
global mapvector; %kell látni a vektort 
global n; %kell látni, hogy melyik colormapen vagyok
szin=rand(30, 30); %rand mx generál
colormap(mapvector{n}); %megfelelõ colormappal ábrázol
imagesc(szin); %kirajz
%%

% --- Executes on button press in changecolormap.
function changecolormap_Callback(hObject, eventdata, handles)
% hObject    handle to changecolormap (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%% saját rész: change colormap gomb lenyomásásakor ez történik:
global n;
global mapvector;
%lehetséges colormappek (cell-ben tárolva, mert szavak):
mapvector={'Jet', 'HSV', 'Hot', 'Cool', 'Spring', 'Summer', 'Autumn', 'Winter', 'Gray', 'Bone', 'Copper', 'Pink'};
% a gomb lenyomásakor lépek egyet a colormapen, a következõvel rajzolok ki
if n==length(mapvector) %a vektor végén újrakezden
    n=1;
else
n=n+1; %gombnyomásra lép a következõ colormapre
end
set(handles.colormapkiir, 'String', mapvector{n}); %kiírom a szöveg mezõbe, melyik colormapet használom
%%

function colormapkiir_Callback(hObject, eventdata, handles)
% hObject    handle to colormapkiir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of colormapkiir as text
%        str2double(get(hObject,'String')) returns contents of colormapkiir as a double


% --- Executes during object creation, after setting all properties.
function colormapkiir_CreateFcn(hObject, eventdata, handles)
% hObject    handle to colormapkiir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
